# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ipc.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import state_pb2 as state__pb2
from . import transforms_pb2 as transforms__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ipc.proto',
  package='io.casperlabs.ipc',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\tipc.proto\x12\x11io.casperlabs.ipc\x1a\x0bstate.proto\x1a\x10transforms.proto\"(\n\nDeployCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x0c\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\x0c\"J\n\x12StoredContractHash\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\x0c\x12\x18\n\x10\x65ntry_point_name\x18\x03 \x01(\t\"J\n\x12StoredContractName\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x02 \x01(\x0c\x12\x18\n\x10\x65ntry_point_name\x18\x03 \x01(\t\"t\n\x15StoredContractPackage\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\x07version\x18\x02 \x01(\rH\x00\x12\x18\n\x10\x65ntry_point_name\x18\x03 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x01(\x0c\x42\x12\n\x10optional_version\"x\n\x19StoredContractPackageHash\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\x12\x11\n\x07version\x18\x02 \x01(\rH\x00\x12\x18\n\x10\x65ntry_point_name\x18\x03 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x01(\x0c\x42\x12\n\x10optional_version\"\x18\n\x08Transfer\x12\x0c\n\x04\x61rgs\x18\x01 \x01(\x0c\"\xb1\x03\n\rDeployPayload\x12\x34\n\x0b\x64\x65ploy_code\x18\x01 \x01(\x0b\x32\x1d.io.casperlabs.ipc.DeployCodeH\x00\x12\x45\n\x14stored_contract_hash\x18\x02 \x01(\x0b\x32%.io.casperlabs.ipc.StoredContractHashH\x00\x12\x45\n\x14stored_contract_name\x18\x03 \x01(\x0b\x32%.io.casperlabs.ipc.StoredContractNameH\x00\x12J\n\x16stored_package_by_name\x18\x05 \x01(\x0b\x32(.io.casperlabs.ipc.StoredContractPackageH\x00\x12N\n\x16stored_package_by_hash\x18\x06 \x01(\x0b\x32,.io.casperlabs.ipc.StoredContractPackageHashH\x00\x12/\n\x08transfer\x18\x07 \x01(\x0b\x32\x1b.io.casperlabs.ipc.TransferH\x00\x42\t\n\x07payloadJ\x04\x08\x04\x10\x05\"c\n\x04\x42ond\x12\x1e\n\x16validator_account_hash\x18\x01 \x01(\x0c\x12;\n\x05stake\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigInt\"\xd3\x01\n\nDeployItem\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0c\x12\x31\n\x07session\x18\x03 \x01(\x0b\x32 .io.casperlabs.ipc.DeployPayload\x12\x31\n\x07payment\x18\x04 \x01(\x0b\x32 .io.casperlabs.ipc.DeployPayload\x12\x11\n\tgas_price\x18\x06 \x01(\x04\x12\x1a\n\x12\x61uthorization_keys\x18\x08 \x03(\x0c\x12\x13\n\x0b\x64\x65ploy_hash\x18\t \x01(\x0cJ\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\xc0\x01\n\x0e\x45xecuteRequest\x12\x19\n\x11parent_state_hash\x18\x01 \x01(\x0c\x12\x12\n\nblock_time\x18\x02 \x01(\x04\x12.\n\x07\x64\x65ploys\x18\x03 \x03(\x0b\x32\x1d.io.casperlabs.ipc.DeployItem\x12O\n\x10protocol_version\x18\x04 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"\x88\x01\n\x0f\x45xecuteResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x1d.io.casperlabs.ipc.ExecResultH\x00\x12\x39\n\x0emissing_parent\x18\x02 \x01(\x0b\x32\x1f.io.casperlabs.ipc.RootNotFoundH\x00\x42\x08\n\x06result\"E\n\nExecResult\x12\x37\n\x0e\x64\x65ploy_results\x18\x02 \x03(\x0b\x32\x1f.io.casperlabs.ipc.DeployResult\"\x1c\n\x0cRootNotFound\x12\x0c\n\x04hash\x18\x01 \x01(\x0c\"\xab\x01\n\rCommitRequest\x12\x15\n\rprestate_hash\x18\x01 \x01(\x0c\x12\x32\n\x07\x65\x66\x66\x65\x63ts\x18\x02 \x03(\x0b\x32!.io.casperlabs.ipc.TransformEntry\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"Z\n\x0c\x43ommitResult\x12\x16\n\x0epoststate_hash\x18\x01 \x01(\x0c\x12\x32\n\x11\x62onded_validators\x18\x02 \x03(\x0b\x32\x17.io.casperlabs.ipc.Bond\"\xca\x02\n\x0e\x43ommitResponse\x12\x32\n\x07success\x18\x01 \x01(\x0b\x32\x1f.io.casperlabs.ipc.CommitResultH\x00\x12;\n\x10missing_prestate\x18\x02 \x01(\x0b\x32\x1f.io.casperlabs.ipc.RootNotFoundH\x00\x12\x42\n\rkey_not_found\x18\x03 \x01(\x0b\x32).io.casperlabs.casper.consensus.state.KeyH\x00\x12\x38\n\rtype_mismatch\x18\x04 \x01(\x0b\x32\x1f.io.casperlabs.ipc.TypeMismatchH\x00\x12?\n\x10\x66\x61iled_transform\x18\x05 \x01(\x0b\x32#.io.casperlabs.ipc.PostEffectsErrorH\x00\x42\x08\n\x06result\"\xbd\x01\n\x02Op\x12)\n\x04read\x18\x01 \x01(\x0b\x32\x19.io.casperlabs.ipc.ReadOpH\x00\x12+\n\x05write\x18\x02 \x01(\x0b\x32\x1a.io.casperlabs.ipc.WriteOpH\x00\x12\'\n\x03\x61\x64\x64\x18\x03 \x01(\x0b\x32\x18.io.casperlabs.ipc.AddOpH\x00\x12\'\n\x04noop\x18\x04 \x01(\x0b\x32\x17.io.casperlabs.ipc.NoOpH\x00\x42\r\n\x0bop_instance\"\x08\n\x06ReadOp\"\t\n\x07WriteOp\"\x07\n\x05\x41\x64\x64Op\"\x06\n\x04NoOp\"\x85\x01\n\x0cStorageError\x12\x37\n\nbytes_repr\x18\x01 \x01(\x0b\x32!.io.casperlabs.ipc.BytesReprErrorH\x00\x12*\n\x03rkv\x18\x02 \x01(\x0b\x32\x1b.io.casperlabs.ipc.RkvErrorH\x00\x42\x10\n\x0e\x65rror_instance\"\xcd\x01\n\x0e\x42ytesReprError\x12\x38\n\tearly_end\x18\x01 \x01(\x0b\x32#.io.casperlabs.ipc.EarlyEndOfStreamH\x00\x12\x38\n\nformatting\x18\x02 \x01(\x0b\x32\".io.casperlabs.ipc.FormattingErrorH\x00\x12\x35\n\tleft_over\x18\x03 \x01(\x0b\x32 .io.casperlabs.ipc.LeftOverBytesH\x00\x42\x10\n\x0e\x65rror_instance\"\x12\n\x10\x45\x61rlyEndOfStream\"\x11\n\x0f\x46ormattingError\"\x0f\n\rLeftOverBytes\"\x1d\n\x08RkvError\x12\x11\n\terror_msg\x18\x01 \x01(\t\"k\n\x07OpEntry\x12\x36\n\x03key\x18\x01 \x01(\x0b\x32).io.casperlabs.casper.consensus.state.Key\x12(\n\toperation\x18\x02 \x01(\x0b\x32\x15.io.casperlabs.ipc.Op\"w\n\x0f\x45xecutionEffect\x12*\n\x06op_map\x18\x01 \x03(\x0b\x32\x1a.io.casperlabs.ipc.OpEntry\x12\x38\n\rtransform_map\x18\x02 \x03(\x0b\x32!.io.casperlabs.ipc.TransformEntry\"\xd2\x01\n\x0b\x44\x65ployError\x12\x41\n\tgas_error\x18\x01 \x01(\x0b\x32,.io.casperlabs.ipc.DeployError.OutOfGasErrorH\x00\x12\x43\n\nexec_error\x18\x02 \x01(\x0b\x32-.io.casperlabs.ipc.DeployError.ExecutionErrorH\x00\x1a\x0f\n\rOutOfGasError\x1a!\n\x0e\x45xecutionError\x12\x0f\n\x07message\x18\x01 \x01(\tB\x07\n\x05value\"\x95\x03\n\x0c\x44\x65ployResult\x12S\n\x14precondition_failure\x18\x02 \x01(\x0b\x32\x33.io.casperlabs.ipc.DeployResult.PreconditionFailureH\x00\x12K\n\x10\x65xecution_result\x18\x03 \x01(\x0b\x32/.io.casperlabs.ipc.DeployResult.ExecutionResultH\x00\x1a&\n\x13PreconditionFailure\x12\x0f\n\x07message\x18\x01 \x01(\t\x1a\xb1\x01\n\x0f\x45xecutionResult\x12\x33\n\x07\x65\x66\x66\x65\x63ts\x18\x01 \x01(\x0b\x32\".io.casperlabs.ipc.ExecutionEffect\x12-\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1e.io.casperlabs.ipc.DeployError\x12:\n\x04\x63ost\x18\x03 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigIntB\x07\n\x05value\"#\n\x10PostEffectsError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xbe\x01\n\x0cQueryRequest\x12\x12\n\nstate_hash\x18\x01 \x01(\x0c\x12;\n\x08\x62\x61se_key\x18\x02 \x01(\x0b\x32).io.casperlabs.casper.consensus.state.Key\x12\x0c\n\x04path\x18\x03 \x03(\t\x12O\n\x10protocol_version\x18\x04 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"E\n\rQueryResponse\x12\x11\n\x07success\x18\x03 \x01(\x0cH\x00\x12\x11\n\x07\x66\x61ilure\x18\x02 \x01(\tH\x00\x42\x08\n\x06resultJ\x04\x08\x01\x10\x02\"[\n\rGenesisResult\x12\x16\n\x0epoststate_hash\x18\x01 \x01(\x0c\x12\x32\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\x0b\x32\".io.casperlabs.ipc.ExecutionEffect\"%\n\x12GenesisDeployError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x90\x01\n\x0fGenesisResponse\x12\x33\n\x07success\x18\x01 \x01(\x0b\x32 .io.casperlabs.ipc.GenesisResultH\x00\x12>\n\rfailed_deploy\x18\x02 \x01(\x0b\x32%.io.casperlabs.ipc.GenesisDeployErrorH\x00\x42\x08\n\x06result\"\x93\x0f\n\tChainSpec\x12;\n\x07genesis\x18\x01 \x01(\x0b\x32*.io.casperlabs.ipc.ChainSpec.GenesisConfig\x12;\n\x08upgrades\x18\x02 \x03(\x0b\x32).io.casperlabs.ipc.ChainSpec.UpgradePoint\x1a\x90\x06\n\rGenesisConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x12@\n\rdeploy_config\x18\x08 \x01(\x0b\x32).io.casperlabs.ipc.ChainSpec.DeployConfig\x12\x42\n\x0ehighway_config\x18\t \x01(\x0b\x32*.io.casperlabs.ipc.ChainSpec.HighwayConfig\x12H\n\tee_config\x18\x0b \x01(\x0b\x32\x35.io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig\x1a\x9e\x03\n\nExecConfig\x12\x16\n\x0emint_installer\x18\x01 \x01(\x0c\x12\x15\n\rpos_installer\x18\x02 \x01(\x0c\x12\"\n\x1astandard_payment_installer\x18\x03 \x01(\x0c\x12V\n\x08\x61\x63\x63ounts\x18\x04 \x03(\x0b\x32\x44.io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.GenesisAccount\x12\x35\n\x05\x63osts\x18\x05 \x01(\x0b\x32&.io.casperlabs.ipc.ChainSpec.CostTable\x1a\xad\x01\n\x0eGenesisAccount\x12\x17\n\x0fpublic_key_hash\x18\x01 \x01(\x0c\x12=\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigInt\x12\x43\n\rbonded_amount\x18\x03 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigIntJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\n\x10\x0bJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08\x1av\n\x0c\x44\x65ployConfig\x12\x16\n\x0emax_ttl_millis\x18\x02 \x01(\r\x12\x18\n\x10max_dependencies\x18\x03 \x01(\r\x12\x1c\n\x14max_block_size_bytes\x18\x04 \x01(\r\x12\x16\n\x0emax_block_cost\x18\x05 \x01(\x04\x1a\xeb\x01\n\rHighwayConfig\x12#\n\x1bgenesis_era_start_timestamp\x18\x01 \x01(\x04\x12\x1b\n\x13\x65ra_duration_millis\x18\x02 \x01(\x04\x12\x1f\n\x17\x62ooking_duration_millis\x18\x03 \x01(\x04\x12\x1f\n\x17\x65ntropy_duration_millis\x18\x04 \x01(\x04\x12%\n\x1dvoting_period_duration_millis\x18\x05 \x01(\x04\x12\"\n\x1avoting_period_summit_level\x18\x06 \x01(\r\x12\x0b\n\x03\x66tt\x18\x07 \x01(\x01\x1a\x8c\x02\n\tCostTable\x12>\n\x04wasm\x18\x01 \x01(\x0b\x32\x30.io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts\x1a\xbe\x01\n\tWasmCosts\x12\x0f\n\x07regular\x18\x01 \x01(\r\x12\x0b\n\x03\x64iv\x18\x02 \x01(\r\x12\x0b\n\x03mul\x18\x03 \x01(\r\x12\x0b\n\x03mem\x18\x04 \x01(\r\x12\x13\n\x0binitial_mem\x18\x05 \x01(\r\x12\x10\n\x08grow_mem\x18\x06 \x01(\r\x12\x0e\n\x06memcpy\x18\x07 \x01(\r\x12\x18\n\x10max_stack_height\x18\x08 \x01(\r\x12\x13\n\x0bopcodes_mul\x18\t \x01(\r\x12\x13\n\x0bopcodes_div\x18\n \x01(\r\x1a\xe2\x02\n\x0cUpgradePoint\x12\x46\n\x10\x61\x63tivation_point\x18\x01 \x01(\x0b\x32,.io.casperlabs.ipc.ChainSpec.ActivationPoint\x12O\n\x10protocol_version\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x12\x38\n\x11upgrade_installer\x18\x03 \x01(\x0b\x32\x1d.io.casperlabs.ipc.DeployCode\x12\x39\n\tnew_costs\x18\x04 \x01(\x0b\x32&.io.casperlabs.ipc.ChainSpec.CostTable\x12\x44\n\x11new_deploy_config\x18\x05 \x01(\x0b\x32).io.casperlabs.ipc.ChainSpec.DeployConfig\x1a\x1f\n\x0f\x41\x63tivationPoint\x12\x0c\n\x04rank\x18\x01 \x01(\x04\"\xbe\x01\n\x0eUpgradeRequest\x12\x19\n\x11parent_state_hash\x18\x01 \x01(\x0c\x12@\n\rupgrade_point\x18\x02 \x01(\x0b\x32).io.casperlabs.ipc.ChainSpec.UpgradePoint\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"\\\n\rUpgradeResult\x12\x17\n\x0fpost_state_hash\x18\x01 \x01(\x0c\x12\x32\n\x06\x65\x66\x66\x65\x63t\x18\x02 \x01(\x0b\x32\".io.casperlabs.ipc.ExecutionEffect\"%\n\x12UpgradeDeployError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x90\x01\n\x0fUpgradeResponse\x12\x33\n\x07success\x18\x01 \x01(\x0b\x32 .io.casperlabs.ipc.UpgradeResultH\x00\x12>\n\rfailed_deploy\x18\x02 \x01(\x0b\x32%.io.casperlabs.ipc.UpgradeDeployErrorH\x00\x42\x08\n\x06result\"}\n\x0f\x42idStateRequest\x12\x19\n\x11parent_state_hash\x18\x01 \x01(\x0c\x12O\n\x10protocol_version\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"\x89\x01\n\x08\x42idState\x12-\n\x04\x62ids\x18\x01 \x03(\x0b\x32\x1f.io.casperlabs.ipc.BidState.Bid\x1aN\n\x03\x42id\x12\n\n\x02id\x18\x01 \x01(\x0c\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigInt\"\x87\x01\n\x10\x42idStateResponse\x12.\n\x07success\x18\x01 \x01(\x0b\x32\x1b.io.casperlabs.ipc.BidStateH\x00\x12\x39\n\x0emissing_parent\x18\x02 \x01(\x0b\x32\x1f.io.casperlabs.ipc.RootNotFoundH\x00\x42\x08\n\x06result\"\xba\x02\n\x18\x44istributeRewardsRequest\x12\x19\n\x11parent_state_hash\x18\x01 \x01(\x0c\x12L\n\x07rewards\x18\x02 \x03(\x0b\x32;.io.casperlabs.ipc.DistributeRewardsRequest.ValidatorReward\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x1a\x64\n\x0fValidatorReward\x12\x14\n\x0cvalidator_id\x18\x01 \x01(\x0c\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigInt\"(\n\x15\x44istibuteRewardsError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xcf\x01\n\x19\x44istributeRewardsResponse\x12\x32\n\x07success\x18\x01 \x01(\x0b\x32\x1f.io.casperlabs.ipc.CommitResultH\x00\x12\x39\n\x0emissing_parent\x18\x02 \x01(\x0b\x32\x1f.io.casperlabs.ipc.RootNotFoundH\x00\x12\x39\n\x05\x65rror\x18\x03 \x01(\x0b\x32(.io.casperlabs.ipc.DistibuteRewardsErrorH\x00\x42\x08\n\x06result\"\xa0\x02\n\x0cSlashRequest\x12\x19\n\x11parent_state_hash\x18\x01 \x01(\x0c\x12?\n\x07slashes\x18\x02 \x03(\x0b\x32..io.casperlabs.ipc.SlashRequest.ValidatorSlash\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x1a\x63\n\x0eValidatorSlash\x12\x14\n\x0cvalidator_id\x18\x01 \x01(\x0c\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.io.casperlabs.casper.consensus.state.BigInt\"\x1d\n\nSlashError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xb8\x01\n\rSlashResponse\x12\x32\n\x07success\x18\x01 \x01(\x0b\x32\x1f.io.casperlabs.ipc.CommitResultH\x00\x12\x39\n\x0emissing_parent\x18\x02 \x01(\x0b\x32\x1f.io.casperlabs.ipc.RootNotFoundH\x00\x12.\n\x05\x65rror\x18\x03 \x01(\x0b\x32\x1d.io.casperlabs.ipc.SlashErrorH\x00\x42\x08\n\x06result\"\x95\x01\n\x13UnbondPayoutRequest\x12\x19\n\x11parent_state_hash\x18\x01 \x01(\x0c\x12\x12\n\nera_height\x18\x02 \x01(\x04\x12O\n\x10protocol_version\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\"$\n\x11UnbondPayoutError\x12\x0f\n\x07message\x18\x01 \x01(\t\"\xc6\x01\n\x14UnbondPayoutResponse\x12\x32\n\x07success\x18\x01 \x01(\x0b\x32\x1f.io.casperlabs.ipc.CommitResultH\x00\x12\x39\n\x0emissing_parent\x18\x02 \x01(\x0b\x32\x1f.io.casperlabs.ipc.RootNotFoundH\x00\x12\x35\n\x05\x65rror\x18\x03 \x01(\x0b\x32$.io.casperlabs.ipc.UnbondPayoutErrorH\x00\x42\x08\n\x06result\"\xcb\x01\n\x11RunGenesisRequest\x12\x1b\n\x13genesis_config_hash\x18\x01 \x01(\x0c\x12O\n\x10protocol_version\x18\x02 \x01(\x0b\x32\x35.io.casperlabs.casper.consensus.state.ProtocolVersion\x12H\n\tee_config\x18\x03 \x01(\x0b\x32\x35.io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig2\xb7\x06\n\x16\x45xecutionEngineService\x12O\n\x06\x63ommit\x12 .io.casperlabs.ipc.CommitRequest\x1a!.io.casperlabs.ipc.CommitResponse\"\x00\x12L\n\x05query\x12\x1f.io.casperlabs.ipc.QueryRequest\x1a .io.casperlabs.ipc.QueryResponse\"\x00\x12R\n\x07\x65xecute\x12!.io.casperlabs.ipc.ExecuteRequest\x1a\".io.casperlabs.ipc.ExecuteResponse\"\x00\x12Y\n\x0brun_genesis\x12$.io.casperlabs.ipc.RunGenesisRequest\x1a\".io.casperlabs.ipc.GenesisResponse\"\x00\x12R\n\x07upgrade\x12!.io.casperlabs.ipc.UpgradeRequest\x1a\".io.casperlabs.ipc.UpgradeResponse\"\x00\x12V\n\tbid_state\x12\".io.casperlabs.ipc.BidStateRequest\x1a#.io.casperlabs.ipc.BidStateResponse\"\x00\x12q\n\x12\x64istribute_rewards\x12+.io.casperlabs.ipc.DistributeRewardsRequest\x1a,.io.casperlabs.ipc.DistributeRewardsResponse\"\x00\x12L\n\x05slash\x12\x1f.io.casperlabs.ipc.SlashRequest\x1a .io.casperlabs.ipc.SlashResponse\"\x00\x12\x62\n\runbond_payout\x12&.io.casperlabs.ipc.UnbondPayoutRequest\x1a\'.io.casperlabs.ipc.UnbondPayoutResponse\"\x00\x62\x06proto3'
  ,
  dependencies=[state__pb2.DESCRIPTOR,transforms__pb2.DESCRIPTOR,])




_DEPLOYCODE = _descriptor.Descriptor(
  name='DeployCode',
  full_name='io.casperlabs.ipc.DeployCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='io.casperlabs.ipc.DeployCode.code', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.ipc.DeployCode.args', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=63,
  serialized_end=103,
)


_STOREDCONTRACTHASH = _descriptor.Descriptor(
  name='StoredContractHash',
  full_name='io.casperlabs.ipc.StoredContractHash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.ipc.StoredContractHash.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.ipc.StoredContractHash.args', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_point_name', full_name='io.casperlabs.ipc.StoredContractHash.entry_point_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=179,
)


_STOREDCONTRACTNAME = _descriptor.Descriptor(
  name='StoredContractName',
  full_name='io.casperlabs.ipc.StoredContractName',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.ipc.StoredContractName.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.ipc.StoredContractName.args', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_point_name', full_name='io.casperlabs.ipc.StoredContractName.entry_point_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=255,
)


_STOREDCONTRACTPACKAGE = _descriptor.Descriptor(
  name='StoredContractPackage',
  full_name='io.casperlabs.ipc.StoredContractPackage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.ipc.StoredContractPackage.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='io.casperlabs.ipc.StoredContractPackage.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_point_name', full_name='io.casperlabs.ipc.StoredContractPackage.entry_point_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.ipc.StoredContractPackage.args', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='optional_version', full_name='io.casperlabs.ipc.StoredContractPackage.optional_version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=257,
  serialized_end=373,
)


_STOREDCONTRACTPACKAGEHASH = _descriptor.Descriptor(
  name='StoredContractPackageHash',
  full_name='io.casperlabs.ipc.StoredContractPackageHash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.ipc.StoredContractPackageHash.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='io.casperlabs.ipc.StoredContractPackageHash.version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_point_name', full_name='io.casperlabs.ipc.StoredContractPackageHash.entry_point_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.ipc.StoredContractPackageHash.args', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='optional_version', full_name='io.casperlabs.ipc.StoredContractPackageHash.optional_version',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=375,
  serialized_end=495,
)


_TRANSFER = _descriptor.Descriptor(
  name='Transfer',
  full_name='io.casperlabs.ipc.Transfer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='args', full_name='io.casperlabs.ipc.Transfer.args', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=521,
)


_DEPLOYPAYLOAD = _descriptor.Descriptor(
  name='DeployPayload',
  full_name='io.casperlabs.ipc.DeployPayload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_code', full_name='io.casperlabs.ipc.DeployPayload.deploy_code', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_contract_hash', full_name='io.casperlabs.ipc.DeployPayload.stored_contract_hash', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_contract_name', full_name='io.casperlabs.ipc.DeployPayload.stored_contract_name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_package_by_name', full_name='io.casperlabs.ipc.DeployPayload.stored_package_by_name', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stored_package_by_hash', full_name='io.casperlabs.ipc.DeployPayload.stored_package_by_hash', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transfer', full_name='io.casperlabs.ipc.DeployPayload.transfer', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='io.casperlabs.ipc.DeployPayload.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=524,
  serialized_end=957,
)


_BOND = _descriptor.Descriptor(
  name='Bond',
  full_name='io.casperlabs.ipc.Bond',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_account_hash', full_name='io.casperlabs.ipc.Bond.validator_account_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stake', full_name='io.casperlabs.ipc.Bond.stake', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=959,
  serialized_end=1058,
)


_DEPLOYITEM = _descriptor.Descriptor(
  name='DeployItem',
  full_name='io.casperlabs.ipc.DeployItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='io.casperlabs.ipc.DeployItem.address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session', full_name='io.casperlabs.ipc.DeployItem.session', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payment', full_name='io.casperlabs.ipc.DeployItem.payment', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_price', full_name='io.casperlabs.ipc.DeployItem.gas_price', index=3,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authorization_keys', full_name='io.casperlabs.ipc.DeployItem.authorization_keys', index=4,
      number=8, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_hash', full_name='io.casperlabs.ipc.DeployItem.deploy_hash', index=5,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1061,
  serialized_end=1272,
)


_EXECUTEREQUEST = _descriptor.Descriptor(
  name='ExecuteRequest',
  full_name='io.casperlabs.ipc.ExecuteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_state_hash', full_name='io.casperlabs.ipc.ExecuteRequest.parent_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_time', full_name='io.casperlabs.ipc.ExecuteRequest.block_time', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploys', full_name='io.casperlabs.ipc.ExecuteRequest.deploys', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.ExecuteRequest.protocol_version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1275,
  serialized_end=1467,
)


_EXECUTERESPONSE = _descriptor.Descriptor(
  name='ExecuteResponse',
  full_name='io.casperlabs.ipc.ExecuteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.ExecuteResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_parent', full_name='io.casperlabs.ipc.ExecuteResponse.missing_parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.ExecuteResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1470,
  serialized_end=1606,
)


_EXECRESULT = _descriptor.Descriptor(
  name='ExecResult',
  full_name='io.casperlabs.ipc.ExecResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deploy_results', full_name='io.casperlabs.ipc.ExecResult.deploy_results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1608,
  serialized_end=1677,
)


_ROOTNOTFOUND = _descriptor.Descriptor(
  name='RootNotFound',
  full_name='io.casperlabs.ipc.RootNotFound',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='io.casperlabs.ipc.RootNotFound.hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1679,
  serialized_end=1707,
)


_COMMITREQUEST = _descriptor.Descriptor(
  name='CommitRequest',
  full_name='io.casperlabs.ipc.CommitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prestate_hash', full_name='io.casperlabs.ipc.CommitRequest.prestate_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effects', full_name='io.casperlabs.ipc.CommitRequest.effects', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.CommitRequest.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1710,
  serialized_end=1881,
)


_COMMITRESULT = _descriptor.Descriptor(
  name='CommitResult',
  full_name='io.casperlabs.ipc.CommitResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poststate_hash', full_name='io.casperlabs.ipc.CommitResult.poststate_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bonded_validators', full_name='io.casperlabs.ipc.CommitResult.bonded_validators', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1883,
  serialized_end=1973,
)


_COMMITRESPONSE = _descriptor.Descriptor(
  name='CommitResponse',
  full_name='io.casperlabs.ipc.CommitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.CommitResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_prestate', full_name='io.casperlabs.ipc.CommitResponse.missing_prestate', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_not_found', full_name='io.casperlabs.ipc.CommitResponse.key_not_found', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_mismatch', full_name='io.casperlabs.ipc.CommitResponse.type_mismatch', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_transform', full_name='io.casperlabs.ipc.CommitResponse.failed_transform', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.CommitResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1976,
  serialized_end=2306,
)


_OP = _descriptor.Descriptor(
  name='Op',
  full_name='io.casperlabs.ipc.Op',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='read', full_name='io.casperlabs.ipc.Op.read', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='write', full_name='io.casperlabs.ipc.Op.write', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='add', full_name='io.casperlabs.ipc.Op.add', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noop', full_name='io.casperlabs.ipc.Op.noop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='op_instance', full_name='io.casperlabs.ipc.Op.op_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2309,
  serialized_end=2498,
)


_READOP = _descriptor.Descriptor(
  name='ReadOp',
  full_name='io.casperlabs.ipc.ReadOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2500,
  serialized_end=2508,
)


_WRITEOP = _descriptor.Descriptor(
  name='WriteOp',
  full_name='io.casperlabs.ipc.WriteOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2510,
  serialized_end=2519,
)


_ADDOP = _descriptor.Descriptor(
  name='AddOp',
  full_name='io.casperlabs.ipc.AddOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2521,
  serialized_end=2528,
)


_NOOP = _descriptor.Descriptor(
  name='NoOp',
  full_name='io.casperlabs.ipc.NoOp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2530,
  serialized_end=2536,
)


_STORAGEERROR = _descriptor.Descriptor(
  name='StorageError',
  full_name='io.casperlabs.ipc.StorageError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bytes_repr', full_name='io.casperlabs.ipc.StorageError.bytes_repr', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rkv', full_name='io.casperlabs.ipc.StorageError.rkv', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_instance', full_name='io.casperlabs.ipc.StorageError.error_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2539,
  serialized_end=2672,
)


_BYTESREPRERROR = _descriptor.Descriptor(
  name='BytesReprError',
  full_name='io.casperlabs.ipc.BytesReprError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='early_end', full_name='io.casperlabs.ipc.BytesReprError.early_end', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatting', full_name='io.casperlabs.ipc.BytesReprError.formatting', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='left_over', full_name='io.casperlabs.ipc.BytesReprError.left_over', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='error_instance', full_name='io.casperlabs.ipc.BytesReprError.error_instance',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2675,
  serialized_end=2880,
)


_EARLYENDOFSTREAM = _descriptor.Descriptor(
  name='EarlyEndOfStream',
  full_name='io.casperlabs.ipc.EarlyEndOfStream',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2882,
  serialized_end=2900,
)


_FORMATTINGERROR = _descriptor.Descriptor(
  name='FormattingError',
  full_name='io.casperlabs.ipc.FormattingError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2902,
  serialized_end=2919,
)


_LEFTOVERBYTES = _descriptor.Descriptor(
  name='LeftOverBytes',
  full_name='io.casperlabs.ipc.LeftOverBytes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2921,
  serialized_end=2936,
)


_RKVERROR = _descriptor.Descriptor(
  name='RkvError',
  full_name='io.casperlabs.ipc.RkvError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='io.casperlabs.ipc.RkvError.error_msg', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2938,
  serialized_end=2967,
)


_OPENTRY = _descriptor.Descriptor(
  name='OpEntry',
  full_name='io.casperlabs.ipc.OpEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='io.casperlabs.ipc.OpEntry.key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation', full_name='io.casperlabs.ipc.OpEntry.operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2969,
  serialized_end=3076,
)


_EXECUTIONEFFECT = _descriptor.Descriptor(
  name='ExecutionEffect',
  full_name='io.casperlabs.ipc.ExecutionEffect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='op_map', full_name='io.casperlabs.ipc.ExecutionEffect.op_map', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transform_map', full_name='io.casperlabs.ipc.ExecutionEffect.transform_map', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3078,
  serialized_end=3197,
)


_DEPLOYERROR_OUTOFGASERROR = _descriptor.Descriptor(
  name='OutOfGasError',
  full_name='io.casperlabs.ipc.DeployError.OutOfGasError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3351,
  serialized_end=3366,
)

_DEPLOYERROR_EXECUTIONERROR = _descriptor.Descriptor(
  name='ExecutionError',
  full_name='io.casperlabs.ipc.DeployError.ExecutionError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.DeployError.ExecutionError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3368,
  serialized_end=3401,
)

_DEPLOYERROR = _descriptor.Descriptor(
  name='DeployError',
  full_name='io.casperlabs.ipc.DeployError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gas_error', full_name='io.casperlabs.ipc.DeployError.gas_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_error', full_name='io.casperlabs.ipc.DeployError.exec_error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYERROR_OUTOFGASERROR, _DEPLOYERROR_EXECUTIONERROR, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.ipc.DeployError.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3200,
  serialized_end=3410,
)


_DEPLOYRESULT_PRECONDITIONFAILURE = _descriptor.Descriptor(
  name='PreconditionFailure',
  full_name='io.casperlabs.ipc.DeployResult.PreconditionFailure',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.DeployResult.PreconditionFailure.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3591,
  serialized_end=3629,
)

_DEPLOYRESULT_EXECUTIONRESULT = _descriptor.Descriptor(
  name='ExecutionResult',
  full_name='io.casperlabs.ipc.DeployResult.ExecutionResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effects', full_name='io.casperlabs.ipc.DeployResult.ExecutionResult.effects', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='io.casperlabs.ipc.DeployResult.ExecutionResult.error', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cost', full_name='io.casperlabs.ipc.DeployResult.ExecutionResult.cost', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3632,
  serialized_end=3809,
)

_DEPLOYRESULT = _descriptor.Descriptor(
  name='DeployResult',
  full_name='io.casperlabs.ipc.DeployResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='precondition_failure', full_name='io.casperlabs.ipc.DeployResult.precondition_failure', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='execution_result', full_name='io.casperlabs.ipc.DeployResult.execution_result', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DEPLOYRESULT_PRECONDITIONFAILURE, _DEPLOYRESULT_EXECUTIONRESULT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='io.casperlabs.ipc.DeployResult.value',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3413,
  serialized_end=3818,
)


_POSTEFFECTSERROR = _descriptor.Descriptor(
  name='PostEffectsError',
  full_name='io.casperlabs.ipc.PostEffectsError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.PostEffectsError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3820,
  serialized_end=3855,
)


_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='io.casperlabs.ipc.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state_hash', full_name='io.casperlabs.ipc.QueryRequest.state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_key', full_name='io.casperlabs.ipc.QueryRequest.base_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='io.casperlabs.ipc.QueryRequest.path', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.QueryRequest.protocol_version', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3858,
  serialized_end=4048,
)


_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='io.casperlabs.ipc.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.QueryResponse.success', index=0,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failure', full_name='io.casperlabs.ipc.QueryResponse.failure', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.QueryResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4050,
  serialized_end=4119,
)


_GENESISRESULT = _descriptor.Descriptor(
  name='GenesisResult',
  full_name='io.casperlabs.ipc.GenesisResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='poststate_hash', full_name='io.casperlabs.ipc.GenesisResult.poststate_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='io.casperlabs.ipc.GenesisResult.effect', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4121,
  serialized_end=4212,
)


_GENESISDEPLOYERROR = _descriptor.Descriptor(
  name='GenesisDeployError',
  full_name='io.casperlabs.ipc.GenesisDeployError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.GenesisDeployError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4214,
  serialized_end=4251,
)


_GENESISRESPONSE = _descriptor.Descriptor(
  name='GenesisResponse',
  full_name='io.casperlabs.ipc.GenesisResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.GenesisResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_deploy', full_name='io.casperlabs.ipc.GenesisResponse.failed_deploy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.GenesisResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=4254,
  serialized_end=4398,
)


_CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT = _descriptor.Descriptor(
  name='GenesisAccount',
  full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.GenesisAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key_hash', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.GenesisAccount.public_key_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.GenesisAccount.balance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bonded_amount', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.GenesisAccount.bonded_amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5118,
  serialized_end=5291,
)

_CHAINSPEC_GENESISCONFIG_EXECCONFIG = _descriptor.Descriptor(
  name='ExecConfig',
  full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mint_installer', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.mint_installer', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pos_installer', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.pos_installer', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='standard_payment_installer', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.standard_payment_installer', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accounts', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.accounts', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='costs', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.costs', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4877,
  serialized_end=5291,
)

_CHAINSPEC_GENESISCONFIG = _descriptor.Descriptor(
  name='GenesisConfig',
  full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deploy_config', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.deploy_config', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='highway_config', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.highway_config', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ee_config', full_name='io.casperlabs.ipc.ChainSpec.GenesisConfig.ee_config', index=5,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHAINSPEC_GENESISCONFIG_EXECCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4537,
  serialized_end=5321,
)

_CHAINSPEC_DEPLOYCONFIG = _descriptor.Descriptor(
  name='DeployConfig',
  full_name='io.casperlabs.ipc.ChainSpec.DeployConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_ttl_millis', full_name='io.casperlabs.ipc.ChainSpec.DeployConfig.max_ttl_millis', index=0,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_dependencies', full_name='io.casperlabs.ipc.ChainSpec.DeployConfig.max_dependencies', index=1,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_block_size_bytes', full_name='io.casperlabs.ipc.ChainSpec.DeployConfig.max_block_size_bytes', index=2,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_block_cost', full_name='io.casperlabs.ipc.ChainSpec.DeployConfig.max_block_cost', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5323,
  serialized_end=5441,
)

_CHAINSPEC_HIGHWAYCONFIG = _descriptor.Descriptor(
  name='HighwayConfig',
  full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='genesis_era_start_timestamp', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.genesis_era_start_timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='era_duration_millis', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.era_duration_millis', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='booking_duration_millis', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.booking_duration_millis', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entropy_duration_millis', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.entropy_duration_millis', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voting_period_duration_millis', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.voting_period_duration_millis', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voting_period_summit_level', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.voting_period_summit_level', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ftt', full_name='io.casperlabs.ipc.ChainSpec.HighwayConfig.ftt', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5444,
  serialized_end=5679,
)

_CHAINSPEC_COSTTABLE_WASMCOSTS = _descriptor.Descriptor(
  name='WasmCosts',
  full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='regular', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.regular', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='div', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.div', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mul', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.mul', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mem', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.mem', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_mem', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.initial_mem', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grow_mem', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.grow_mem', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memcpy', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.memcpy', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_stack_height', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.max_stack_height', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opcodes_mul', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.opcodes_mul', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='opcodes_div', full_name='io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts.opcodes_div', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5760,
  serialized_end=5950,
)

_CHAINSPEC_COSTTABLE = _descriptor.Descriptor(
  name='CostTable',
  full_name='io.casperlabs.ipc.ChainSpec.CostTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wasm', full_name='io.casperlabs.ipc.ChainSpec.CostTable.wasm', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHAINSPEC_COSTTABLE_WASMCOSTS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5682,
  serialized_end=5950,
)

_CHAINSPEC_UPGRADEPOINT = _descriptor.Descriptor(
  name='UpgradePoint',
  full_name='io.casperlabs.ipc.ChainSpec.UpgradePoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activation_point', full_name='io.casperlabs.ipc.ChainSpec.UpgradePoint.activation_point', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.ChainSpec.UpgradePoint.protocol_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgrade_installer', full_name='io.casperlabs.ipc.ChainSpec.UpgradePoint.upgrade_installer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_costs', full_name='io.casperlabs.ipc.ChainSpec.UpgradePoint.new_costs', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='new_deploy_config', full_name='io.casperlabs.ipc.ChainSpec.UpgradePoint.new_deploy_config', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5953,
  serialized_end=6307,
)

_CHAINSPEC_ACTIVATIONPOINT = _descriptor.Descriptor(
  name='ActivationPoint',
  full_name='io.casperlabs.ipc.ChainSpec.ActivationPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='rank', full_name='io.casperlabs.ipc.ChainSpec.ActivationPoint.rank', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6309,
  serialized_end=6340,
)

_CHAINSPEC = _descriptor.Descriptor(
  name='ChainSpec',
  full_name='io.casperlabs.ipc.ChainSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='genesis', full_name='io.casperlabs.ipc.ChainSpec.genesis', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgrades', full_name='io.casperlabs.ipc.ChainSpec.upgrades', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CHAINSPEC_GENESISCONFIG, _CHAINSPEC_DEPLOYCONFIG, _CHAINSPEC_HIGHWAYCONFIG, _CHAINSPEC_COSTTABLE, _CHAINSPEC_UPGRADEPOINT, _CHAINSPEC_ACTIVATIONPOINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4401,
  serialized_end=6340,
)


_UPGRADEREQUEST = _descriptor.Descriptor(
  name='UpgradeRequest',
  full_name='io.casperlabs.ipc.UpgradeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_state_hash', full_name='io.casperlabs.ipc.UpgradeRequest.parent_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upgrade_point', full_name='io.casperlabs.ipc.UpgradeRequest.upgrade_point', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.UpgradeRequest.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6343,
  serialized_end=6533,
)


_UPGRADERESULT = _descriptor.Descriptor(
  name='UpgradeResult',
  full_name='io.casperlabs.ipc.UpgradeResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='post_state_hash', full_name='io.casperlabs.ipc.UpgradeResult.post_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effect', full_name='io.casperlabs.ipc.UpgradeResult.effect', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6535,
  serialized_end=6627,
)


_UPGRADEDEPLOYERROR = _descriptor.Descriptor(
  name='UpgradeDeployError',
  full_name='io.casperlabs.ipc.UpgradeDeployError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.UpgradeDeployError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6629,
  serialized_end=6666,
)


_UPGRADERESPONSE = _descriptor.Descriptor(
  name='UpgradeResponse',
  full_name='io.casperlabs.ipc.UpgradeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.UpgradeResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='failed_deploy', full_name='io.casperlabs.ipc.UpgradeResponse.failed_deploy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.UpgradeResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6669,
  serialized_end=6813,
)


_BIDSTATEREQUEST = _descriptor.Descriptor(
  name='BidStateRequest',
  full_name='io.casperlabs.ipc.BidStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_state_hash', full_name='io.casperlabs.ipc.BidStateRequest.parent_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.BidStateRequest.protocol_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6815,
  serialized_end=6940,
)


_BIDSTATE_BID = _descriptor.Descriptor(
  name='Bid',
  full_name='io.casperlabs.ipc.BidState.Bid',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='io.casperlabs.ipc.BidState.Bid.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.BidState.Bid.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7002,
  serialized_end=7080,
)

_BIDSTATE = _descriptor.Descriptor(
  name='BidState',
  full_name='io.casperlabs.ipc.BidState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bids', full_name='io.casperlabs.ipc.BidState.bids', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_BIDSTATE_BID, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6943,
  serialized_end=7080,
)


_BIDSTATERESPONSE = _descriptor.Descriptor(
  name='BidStateResponse',
  full_name='io.casperlabs.ipc.BidStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.BidStateResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_parent', full_name='io.casperlabs.ipc.BidStateResponse.missing_parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.BidStateResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7083,
  serialized_end=7218,
)


_DISTRIBUTEREWARDSREQUEST_VALIDATORREWARD = _descriptor.Descriptor(
  name='ValidatorReward',
  full_name='io.casperlabs.ipc.DistributeRewardsRequest.ValidatorReward',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_id', full_name='io.casperlabs.ipc.DistributeRewardsRequest.ValidatorReward.validator_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.DistributeRewardsRequest.ValidatorReward.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7435,
  serialized_end=7535,
)

_DISTRIBUTEREWARDSREQUEST = _descriptor.Descriptor(
  name='DistributeRewardsRequest',
  full_name='io.casperlabs.ipc.DistributeRewardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_state_hash', full_name='io.casperlabs.ipc.DistributeRewardsRequest.parent_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rewards', full_name='io.casperlabs.ipc.DistributeRewardsRequest.rewards', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.DistributeRewardsRequest.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DISTRIBUTEREWARDSREQUEST_VALIDATORREWARD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7221,
  serialized_end=7535,
)


_DISTIBUTEREWARDSERROR = _descriptor.Descriptor(
  name='DistibuteRewardsError',
  full_name='io.casperlabs.ipc.DistibuteRewardsError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.DistibuteRewardsError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7537,
  serialized_end=7577,
)


_DISTRIBUTEREWARDSRESPONSE = _descriptor.Descriptor(
  name='DistributeRewardsResponse',
  full_name='io.casperlabs.ipc.DistributeRewardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.DistributeRewardsResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_parent', full_name='io.casperlabs.ipc.DistributeRewardsResponse.missing_parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='io.casperlabs.ipc.DistributeRewardsResponse.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.DistributeRewardsResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=7580,
  serialized_end=7787,
)


_SLASHREQUEST_VALIDATORSLASH = _descriptor.Descriptor(
  name='ValidatorSlash',
  full_name='io.casperlabs.ipc.SlashRequest.ValidatorSlash',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_id', full_name='io.casperlabs.ipc.SlashRequest.ValidatorSlash.validator_id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='io.casperlabs.ipc.SlashRequest.ValidatorSlash.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7979,
  serialized_end=8078,
)

_SLASHREQUEST = _descriptor.Descriptor(
  name='SlashRequest',
  full_name='io.casperlabs.ipc.SlashRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_state_hash', full_name='io.casperlabs.ipc.SlashRequest.parent_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slashes', full_name='io.casperlabs.ipc.SlashRequest.slashes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.SlashRequest.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SLASHREQUEST_VALIDATORSLASH, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7790,
  serialized_end=8078,
)


_SLASHERROR = _descriptor.Descriptor(
  name='SlashError',
  full_name='io.casperlabs.ipc.SlashError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.SlashError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8080,
  serialized_end=8109,
)


_SLASHRESPONSE = _descriptor.Descriptor(
  name='SlashResponse',
  full_name='io.casperlabs.ipc.SlashResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.SlashResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_parent', full_name='io.casperlabs.ipc.SlashResponse.missing_parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='io.casperlabs.ipc.SlashResponse.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.SlashResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8112,
  serialized_end=8296,
)


_UNBONDPAYOUTREQUEST = _descriptor.Descriptor(
  name='UnbondPayoutRequest',
  full_name='io.casperlabs.ipc.UnbondPayoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='parent_state_hash', full_name='io.casperlabs.ipc.UnbondPayoutRequest.parent_state_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='era_height', full_name='io.casperlabs.ipc.UnbondPayoutRequest.era_height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.UnbondPayoutRequest.protocol_version', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8299,
  serialized_end=8448,
)


_UNBONDPAYOUTERROR = _descriptor.Descriptor(
  name='UnbondPayoutError',
  full_name='io.casperlabs.ipc.UnbondPayoutError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='io.casperlabs.ipc.UnbondPayoutError.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8450,
  serialized_end=8486,
)


_UNBONDPAYOUTRESPONSE = _descriptor.Descriptor(
  name='UnbondPayoutResponse',
  full_name='io.casperlabs.ipc.UnbondPayoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='io.casperlabs.ipc.UnbondPayoutResponse.success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missing_parent', full_name='io.casperlabs.ipc.UnbondPayoutResponse.missing_parent', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='io.casperlabs.ipc.UnbondPayoutResponse.error', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='result', full_name='io.casperlabs.ipc.UnbondPayoutResponse.result',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=8489,
  serialized_end=8687,
)


_RUNGENESISREQUEST = _descriptor.Descriptor(
  name='RunGenesisRequest',
  full_name='io.casperlabs.ipc.RunGenesisRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='genesis_config_hash', full_name='io.casperlabs.ipc.RunGenesisRequest.genesis_config_hash', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='io.casperlabs.ipc.RunGenesisRequest.protocol_version', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ee_config', full_name='io.casperlabs.ipc.RunGenesisRequest.ee_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8690,
  serialized_end=8893,
)

_STOREDCONTRACTPACKAGE.oneofs_by_name['optional_version'].fields.append(
  _STOREDCONTRACTPACKAGE.fields_by_name['version'])
_STOREDCONTRACTPACKAGE.fields_by_name['version'].containing_oneof = _STOREDCONTRACTPACKAGE.oneofs_by_name['optional_version']
_STOREDCONTRACTPACKAGEHASH.oneofs_by_name['optional_version'].fields.append(
  _STOREDCONTRACTPACKAGEHASH.fields_by_name['version'])
_STOREDCONTRACTPACKAGEHASH.fields_by_name['version'].containing_oneof = _STOREDCONTRACTPACKAGEHASH.oneofs_by_name['optional_version']
_DEPLOYPAYLOAD.fields_by_name['deploy_code'].message_type = _DEPLOYCODE
_DEPLOYPAYLOAD.fields_by_name['stored_contract_hash'].message_type = _STOREDCONTRACTHASH
_DEPLOYPAYLOAD.fields_by_name['stored_contract_name'].message_type = _STOREDCONTRACTNAME
_DEPLOYPAYLOAD.fields_by_name['stored_package_by_name'].message_type = _STOREDCONTRACTPACKAGE
_DEPLOYPAYLOAD.fields_by_name['stored_package_by_hash'].message_type = _STOREDCONTRACTPACKAGEHASH
_DEPLOYPAYLOAD.fields_by_name['transfer'].message_type = _TRANSFER
_DEPLOYPAYLOAD.oneofs_by_name['payload'].fields.append(
  _DEPLOYPAYLOAD.fields_by_name['deploy_code'])
_DEPLOYPAYLOAD.fields_by_name['deploy_code'].containing_oneof = _DEPLOYPAYLOAD.oneofs_by_name['payload']
_DEPLOYPAYLOAD.oneofs_by_name['payload'].fields.append(
  _DEPLOYPAYLOAD.fields_by_name['stored_contract_hash'])
_DEPLOYPAYLOAD.fields_by_name['stored_contract_hash'].containing_oneof = _DEPLOYPAYLOAD.oneofs_by_name['payload']
_DEPLOYPAYLOAD.oneofs_by_name['payload'].fields.append(
  _DEPLOYPAYLOAD.fields_by_name['stored_contract_name'])
_DEPLOYPAYLOAD.fields_by_name['stored_contract_name'].containing_oneof = _DEPLOYPAYLOAD.oneofs_by_name['payload']
_DEPLOYPAYLOAD.oneofs_by_name['payload'].fields.append(
  _DEPLOYPAYLOAD.fields_by_name['stored_package_by_name'])
_DEPLOYPAYLOAD.fields_by_name['stored_package_by_name'].containing_oneof = _DEPLOYPAYLOAD.oneofs_by_name['payload']
_DEPLOYPAYLOAD.oneofs_by_name['payload'].fields.append(
  _DEPLOYPAYLOAD.fields_by_name['stored_package_by_hash'])
_DEPLOYPAYLOAD.fields_by_name['stored_package_by_hash'].containing_oneof = _DEPLOYPAYLOAD.oneofs_by_name['payload']
_DEPLOYPAYLOAD.oneofs_by_name['payload'].fields.append(
  _DEPLOYPAYLOAD.fields_by_name['transfer'])
_DEPLOYPAYLOAD.fields_by_name['transfer'].containing_oneof = _DEPLOYPAYLOAD.oneofs_by_name['payload']
_BOND.fields_by_name['stake'].message_type = state__pb2._BIGINT
_DEPLOYITEM.fields_by_name['session'].message_type = _DEPLOYPAYLOAD
_DEPLOYITEM.fields_by_name['payment'].message_type = _DEPLOYPAYLOAD
_EXECUTEREQUEST.fields_by_name['deploys'].message_type = _DEPLOYITEM
_EXECUTEREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_EXECUTERESPONSE.fields_by_name['success'].message_type = _EXECRESULT
_EXECUTERESPONSE.fields_by_name['missing_parent'].message_type = _ROOTNOTFOUND
_EXECUTERESPONSE.oneofs_by_name['result'].fields.append(
  _EXECUTERESPONSE.fields_by_name['success'])
_EXECUTERESPONSE.fields_by_name['success'].containing_oneof = _EXECUTERESPONSE.oneofs_by_name['result']
_EXECUTERESPONSE.oneofs_by_name['result'].fields.append(
  _EXECUTERESPONSE.fields_by_name['missing_parent'])
_EXECUTERESPONSE.fields_by_name['missing_parent'].containing_oneof = _EXECUTERESPONSE.oneofs_by_name['result']
_EXECRESULT.fields_by_name['deploy_results'].message_type = _DEPLOYRESULT
_COMMITREQUEST.fields_by_name['effects'].message_type = transforms__pb2._TRANSFORMENTRY
_COMMITREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_COMMITRESULT.fields_by_name['bonded_validators'].message_type = _BOND
_COMMITRESPONSE.fields_by_name['success'].message_type = _COMMITRESULT
_COMMITRESPONSE.fields_by_name['missing_prestate'].message_type = _ROOTNOTFOUND
_COMMITRESPONSE.fields_by_name['key_not_found'].message_type = state__pb2._KEY
_COMMITRESPONSE.fields_by_name['type_mismatch'].message_type = transforms__pb2._TYPEMISMATCH
_COMMITRESPONSE.fields_by_name['failed_transform'].message_type = _POSTEFFECTSERROR
_COMMITRESPONSE.oneofs_by_name['result'].fields.append(
  _COMMITRESPONSE.fields_by_name['success'])
_COMMITRESPONSE.fields_by_name['success'].containing_oneof = _COMMITRESPONSE.oneofs_by_name['result']
_COMMITRESPONSE.oneofs_by_name['result'].fields.append(
  _COMMITRESPONSE.fields_by_name['missing_prestate'])
_COMMITRESPONSE.fields_by_name['missing_prestate'].containing_oneof = _COMMITRESPONSE.oneofs_by_name['result']
_COMMITRESPONSE.oneofs_by_name['result'].fields.append(
  _COMMITRESPONSE.fields_by_name['key_not_found'])
_COMMITRESPONSE.fields_by_name['key_not_found'].containing_oneof = _COMMITRESPONSE.oneofs_by_name['result']
_COMMITRESPONSE.oneofs_by_name['result'].fields.append(
  _COMMITRESPONSE.fields_by_name['type_mismatch'])
_COMMITRESPONSE.fields_by_name['type_mismatch'].containing_oneof = _COMMITRESPONSE.oneofs_by_name['result']
_COMMITRESPONSE.oneofs_by_name['result'].fields.append(
  _COMMITRESPONSE.fields_by_name['failed_transform'])
_COMMITRESPONSE.fields_by_name['failed_transform'].containing_oneof = _COMMITRESPONSE.oneofs_by_name['result']
_OP.fields_by_name['read'].message_type = _READOP
_OP.fields_by_name['write'].message_type = _WRITEOP
_OP.fields_by_name['add'].message_type = _ADDOP
_OP.fields_by_name['noop'].message_type = _NOOP
_OP.oneofs_by_name['op_instance'].fields.append(
  _OP.fields_by_name['read'])
_OP.fields_by_name['read'].containing_oneof = _OP.oneofs_by_name['op_instance']
_OP.oneofs_by_name['op_instance'].fields.append(
  _OP.fields_by_name['write'])
_OP.fields_by_name['write'].containing_oneof = _OP.oneofs_by_name['op_instance']
_OP.oneofs_by_name['op_instance'].fields.append(
  _OP.fields_by_name['add'])
_OP.fields_by_name['add'].containing_oneof = _OP.oneofs_by_name['op_instance']
_OP.oneofs_by_name['op_instance'].fields.append(
  _OP.fields_by_name['noop'])
_OP.fields_by_name['noop'].containing_oneof = _OP.oneofs_by_name['op_instance']
_STORAGEERROR.fields_by_name['bytes_repr'].message_type = _BYTESREPRERROR
_STORAGEERROR.fields_by_name['rkv'].message_type = _RKVERROR
_STORAGEERROR.oneofs_by_name['error_instance'].fields.append(
  _STORAGEERROR.fields_by_name['bytes_repr'])
_STORAGEERROR.fields_by_name['bytes_repr'].containing_oneof = _STORAGEERROR.oneofs_by_name['error_instance']
_STORAGEERROR.oneofs_by_name['error_instance'].fields.append(
  _STORAGEERROR.fields_by_name['rkv'])
_STORAGEERROR.fields_by_name['rkv'].containing_oneof = _STORAGEERROR.oneofs_by_name['error_instance']
_BYTESREPRERROR.fields_by_name['early_end'].message_type = _EARLYENDOFSTREAM
_BYTESREPRERROR.fields_by_name['formatting'].message_type = _FORMATTINGERROR
_BYTESREPRERROR.fields_by_name['left_over'].message_type = _LEFTOVERBYTES
_BYTESREPRERROR.oneofs_by_name['error_instance'].fields.append(
  _BYTESREPRERROR.fields_by_name['early_end'])
_BYTESREPRERROR.fields_by_name['early_end'].containing_oneof = _BYTESREPRERROR.oneofs_by_name['error_instance']
_BYTESREPRERROR.oneofs_by_name['error_instance'].fields.append(
  _BYTESREPRERROR.fields_by_name['formatting'])
_BYTESREPRERROR.fields_by_name['formatting'].containing_oneof = _BYTESREPRERROR.oneofs_by_name['error_instance']
_BYTESREPRERROR.oneofs_by_name['error_instance'].fields.append(
  _BYTESREPRERROR.fields_by_name['left_over'])
_BYTESREPRERROR.fields_by_name['left_over'].containing_oneof = _BYTESREPRERROR.oneofs_by_name['error_instance']
_OPENTRY.fields_by_name['key'].message_type = state__pb2._KEY
_OPENTRY.fields_by_name['operation'].message_type = _OP
_EXECUTIONEFFECT.fields_by_name['op_map'].message_type = _OPENTRY
_EXECUTIONEFFECT.fields_by_name['transform_map'].message_type = transforms__pb2._TRANSFORMENTRY
_DEPLOYERROR_OUTOFGASERROR.containing_type = _DEPLOYERROR
_DEPLOYERROR_EXECUTIONERROR.containing_type = _DEPLOYERROR
_DEPLOYERROR.fields_by_name['gas_error'].message_type = _DEPLOYERROR_OUTOFGASERROR
_DEPLOYERROR.fields_by_name['exec_error'].message_type = _DEPLOYERROR_EXECUTIONERROR
_DEPLOYERROR.oneofs_by_name['value'].fields.append(
  _DEPLOYERROR.fields_by_name['gas_error'])
_DEPLOYERROR.fields_by_name['gas_error'].containing_oneof = _DEPLOYERROR.oneofs_by_name['value']
_DEPLOYERROR.oneofs_by_name['value'].fields.append(
  _DEPLOYERROR.fields_by_name['exec_error'])
_DEPLOYERROR.fields_by_name['exec_error'].containing_oneof = _DEPLOYERROR.oneofs_by_name['value']
_DEPLOYRESULT_PRECONDITIONFAILURE.containing_type = _DEPLOYRESULT
_DEPLOYRESULT_EXECUTIONRESULT.fields_by_name['effects'].message_type = _EXECUTIONEFFECT
_DEPLOYRESULT_EXECUTIONRESULT.fields_by_name['error'].message_type = _DEPLOYERROR
_DEPLOYRESULT_EXECUTIONRESULT.fields_by_name['cost'].message_type = state__pb2._BIGINT
_DEPLOYRESULT_EXECUTIONRESULT.containing_type = _DEPLOYRESULT
_DEPLOYRESULT.fields_by_name['precondition_failure'].message_type = _DEPLOYRESULT_PRECONDITIONFAILURE
_DEPLOYRESULT.fields_by_name['execution_result'].message_type = _DEPLOYRESULT_EXECUTIONRESULT
_DEPLOYRESULT.oneofs_by_name['value'].fields.append(
  _DEPLOYRESULT.fields_by_name['precondition_failure'])
_DEPLOYRESULT.fields_by_name['precondition_failure'].containing_oneof = _DEPLOYRESULT.oneofs_by_name['value']
_DEPLOYRESULT.oneofs_by_name['value'].fields.append(
  _DEPLOYRESULT.fields_by_name['execution_result'])
_DEPLOYRESULT.fields_by_name['execution_result'].containing_oneof = _DEPLOYRESULT.oneofs_by_name['value']
_QUERYREQUEST.fields_by_name['base_key'].message_type = state__pb2._KEY
_QUERYREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_QUERYRESPONSE.oneofs_by_name['result'].fields.append(
  _QUERYRESPONSE.fields_by_name['success'])
_QUERYRESPONSE.fields_by_name['success'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['result']
_QUERYRESPONSE.oneofs_by_name['result'].fields.append(
  _QUERYRESPONSE.fields_by_name['failure'])
_QUERYRESPONSE.fields_by_name['failure'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['result']
_GENESISRESULT.fields_by_name['effect'].message_type = _EXECUTIONEFFECT
_GENESISRESPONSE.fields_by_name['success'].message_type = _GENESISRESULT
_GENESISRESPONSE.fields_by_name['failed_deploy'].message_type = _GENESISDEPLOYERROR
_GENESISRESPONSE.oneofs_by_name['result'].fields.append(
  _GENESISRESPONSE.fields_by_name['success'])
_GENESISRESPONSE.fields_by_name['success'].containing_oneof = _GENESISRESPONSE.oneofs_by_name['result']
_GENESISRESPONSE.oneofs_by_name['result'].fields.append(
  _GENESISRESPONSE.fields_by_name['failed_deploy'])
_GENESISRESPONSE.fields_by_name['failed_deploy'].containing_oneof = _GENESISRESPONSE.oneofs_by_name['result']
_CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT.fields_by_name['balance'].message_type = state__pb2._BIGINT
_CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT.fields_by_name['bonded_amount'].message_type = state__pb2._BIGINT
_CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT.containing_type = _CHAINSPEC_GENESISCONFIG_EXECCONFIG
_CHAINSPEC_GENESISCONFIG_EXECCONFIG.fields_by_name['accounts'].message_type = _CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT
_CHAINSPEC_GENESISCONFIG_EXECCONFIG.fields_by_name['costs'].message_type = _CHAINSPEC_COSTTABLE
_CHAINSPEC_GENESISCONFIG_EXECCONFIG.containing_type = _CHAINSPEC_GENESISCONFIG
_CHAINSPEC_GENESISCONFIG.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_CHAINSPEC_GENESISCONFIG.fields_by_name['deploy_config'].message_type = _CHAINSPEC_DEPLOYCONFIG
_CHAINSPEC_GENESISCONFIG.fields_by_name['highway_config'].message_type = _CHAINSPEC_HIGHWAYCONFIG
_CHAINSPEC_GENESISCONFIG.fields_by_name['ee_config'].message_type = _CHAINSPEC_GENESISCONFIG_EXECCONFIG
_CHAINSPEC_GENESISCONFIG.containing_type = _CHAINSPEC
_CHAINSPEC_DEPLOYCONFIG.containing_type = _CHAINSPEC
_CHAINSPEC_HIGHWAYCONFIG.containing_type = _CHAINSPEC
_CHAINSPEC_COSTTABLE_WASMCOSTS.containing_type = _CHAINSPEC_COSTTABLE
_CHAINSPEC_COSTTABLE.fields_by_name['wasm'].message_type = _CHAINSPEC_COSTTABLE_WASMCOSTS
_CHAINSPEC_COSTTABLE.containing_type = _CHAINSPEC
_CHAINSPEC_UPGRADEPOINT.fields_by_name['activation_point'].message_type = _CHAINSPEC_ACTIVATIONPOINT
_CHAINSPEC_UPGRADEPOINT.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_CHAINSPEC_UPGRADEPOINT.fields_by_name['upgrade_installer'].message_type = _DEPLOYCODE
_CHAINSPEC_UPGRADEPOINT.fields_by_name['new_costs'].message_type = _CHAINSPEC_COSTTABLE
_CHAINSPEC_UPGRADEPOINT.fields_by_name['new_deploy_config'].message_type = _CHAINSPEC_DEPLOYCONFIG
_CHAINSPEC_UPGRADEPOINT.containing_type = _CHAINSPEC
_CHAINSPEC_ACTIVATIONPOINT.containing_type = _CHAINSPEC
_CHAINSPEC.fields_by_name['genesis'].message_type = _CHAINSPEC_GENESISCONFIG
_CHAINSPEC.fields_by_name['upgrades'].message_type = _CHAINSPEC_UPGRADEPOINT
_UPGRADEREQUEST.fields_by_name['upgrade_point'].message_type = _CHAINSPEC_UPGRADEPOINT
_UPGRADEREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_UPGRADERESULT.fields_by_name['effect'].message_type = _EXECUTIONEFFECT
_UPGRADERESPONSE.fields_by_name['success'].message_type = _UPGRADERESULT
_UPGRADERESPONSE.fields_by_name['failed_deploy'].message_type = _UPGRADEDEPLOYERROR
_UPGRADERESPONSE.oneofs_by_name['result'].fields.append(
  _UPGRADERESPONSE.fields_by_name['success'])
_UPGRADERESPONSE.fields_by_name['success'].containing_oneof = _UPGRADERESPONSE.oneofs_by_name['result']
_UPGRADERESPONSE.oneofs_by_name['result'].fields.append(
  _UPGRADERESPONSE.fields_by_name['failed_deploy'])
_UPGRADERESPONSE.fields_by_name['failed_deploy'].containing_oneof = _UPGRADERESPONSE.oneofs_by_name['result']
_BIDSTATEREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_BIDSTATE_BID.fields_by_name['value'].message_type = state__pb2._BIGINT
_BIDSTATE_BID.containing_type = _BIDSTATE
_BIDSTATE.fields_by_name['bids'].message_type = _BIDSTATE_BID
_BIDSTATERESPONSE.fields_by_name['success'].message_type = _BIDSTATE
_BIDSTATERESPONSE.fields_by_name['missing_parent'].message_type = _ROOTNOTFOUND
_BIDSTATERESPONSE.oneofs_by_name['result'].fields.append(
  _BIDSTATERESPONSE.fields_by_name['success'])
_BIDSTATERESPONSE.fields_by_name['success'].containing_oneof = _BIDSTATERESPONSE.oneofs_by_name['result']
_BIDSTATERESPONSE.oneofs_by_name['result'].fields.append(
  _BIDSTATERESPONSE.fields_by_name['missing_parent'])
_BIDSTATERESPONSE.fields_by_name['missing_parent'].containing_oneof = _BIDSTATERESPONSE.oneofs_by_name['result']
_DISTRIBUTEREWARDSREQUEST_VALIDATORREWARD.fields_by_name['value'].message_type = state__pb2._BIGINT
_DISTRIBUTEREWARDSREQUEST_VALIDATORREWARD.containing_type = _DISTRIBUTEREWARDSREQUEST
_DISTRIBUTEREWARDSREQUEST.fields_by_name['rewards'].message_type = _DISTRIBUTEREWARDSREQUEST_VALIDATORREWARD
_DISTRIBUTEREWARDSREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_DISTRIBUTEREWARDSRESPONSE.fields_by_name['success'].message_type = _COMMITRESULT
_DISTRIBUTEREWARDSRESPONSE.fields_by_name['missing_parent'].message_type = _ROOTNOTFOUND
_DISTRIBUTEREWARDSRESPONSE.fields_by_name['error'].message_type = _DISTIBUTEREWARDSERROR
_DISTRIBUTEREWARDSRESPONSE.oneofs_by_name['result'].fields.append(
  _DISTRIBUTEREWARDSRESPONSE.fields_by_name['success'])
_DISTRIBUTEREWARDSRESPONSE.fields_by_name['success'].containing_oneof = _DISTRIBUTEREWARDSRESPONSE.oneofs_by_name['result']
_DISTRIBUTEREWARDSRESPONSE.oneofs_by_name['result'].fields.append(
  _DISTRIBUTEREWARDSRESPONSE.fields_by_name['missing_parent'])
_DISTRIBUTEREWARDSRESPONSE.fields_by_name['missing_parent'].containing_oneof = _DISTRIBUTEREWARDSRESPONSE.oneofs_by_name['result']
_DISTRIBUTEREWARDSRESPONSE.oneofs_by_name['result'].fields.append(
  _DISTRIBUTEREWARDSRESPONSE.fields_by_name['error'])
_DISTRIBUTEREWARDSRESPONSE.fields_by_name['error'].containing_oneof = _DISTRIBUTEREWARDSRESPONSE.oneofs_by_name['result']
_SLASHREQUEST_VALIDATORSLASH.fields_by_name['value'].message_type = state__pb2._BIGINT
_SLASHREQUEST_VALIDATORSLASH.containing_type = _SLASHREQUEST
_SLASHREQUEST.fields_by_name['slashes'].message_type = _SLASHREQUEST_VALIDATORSLASH
_SLASHREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_SLASHRESPONSE.fields_by_name['success'].message_type = _COMMITRESULT
_SLASHRESPONSE.fields_by_name['missing_parent'].message_type = _ROOTNOTFOUND
_SLASHRESPONSE.fields_by_name['error'].message_type = _SLASHERROR
_SLASHRESPONSE.oneofs_by_name['result'].fields.append(
  _SLASHRESPONSE.fields_by_name['success'])
_SLASHRESPONSE.fields_by_name['success'].containing_oneof = _SLASHRESPONSE.oneofs_by_name['result']
_SLASHRESPONSE.oneofs_by_name['result'].fields.append(
  _SLASHRESPONSE.fields_by_name['missing_parent'])
_SLASHRESPONSE.fields_by_name['missing_parent'].containing_oneof = _SLASHRESPONSE.oneofs_by_name['result']
_SLASHRESPONSE.oneofs_by_name['result'].fields.append(
  _SLASHRESPONSE.fields_by_name['error'])
_SLASHRESPONSE.fields_by_name['error'].containing_oneof = _SLASHRESPONSE.oneofs_by_name['result']
_UNBONDPAYOUTREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_UNBONDPAYOUTRESPONSE.fields_by_name['success'].message_type = _COMMITRESULT
_UNBONDPAYOUTRESPONSE.fields_by_name['missing_parent'].message_type = _ROOTNOTFOUND
_UNBONDPAYOUTRESPONSE.fields_by_name['error'].message_type = _UNBONDPAYOUTERROR
_UNBONDPAYOUTRESPONSE.oneofs_by_name['result'].fields.append(
  _UNBONDPAYOUTRESPONSE.fields_by_name['success'])
_UNBONDPAYOUTRESPONSE.fields_by_name['success'].containing_oneof = _UNBONDPAYOUTRESPONSE.oneofs_by_name['result']
_UNBONDPAYOUTRESPONSE.oneofs_by_name['result'].fields.append(
  _UNBONDPAYOUTRESPONSE.fields_by_name['missing_parent'])
_UNBONDPAYOUTRESPONSE.fields_by_name['missing_parent'].containing_oneof = _UNBONDPAYOUTRESPONSE.oneofs_by_name['result']
_UNBONDPAYOUTRESPONSE.oneofs_by_name['result'].fields.append(
  _UNBONDPAYOUTRESPONSE.fields_by_name['error'])
_UNBONDPAYOUTRESPONSE.fields_by_name['error'].containing_oneof = _UNBONDPAYOUTRESPONSE.oneofs_by_name['result']
_RUNGENESISREQUEST.fields_by_name['protocol_version'].message_type = state__pb2._PROTOCOLVERSION
_RUNGENESISREQUEST.fields_by_name['ee_config'].message_type = _CHAINSPEC_GENESISCONFIG_EXECCONFIG
DESCRIPTOR.message_types_by_name['DeployCode'] = _DEPLOYCODE
DESCRIPTOR.message_types_by_name['StoredContractHash'] = _STOREDCONTRACTHASH
DESCRIPTOR.message_types_by_name['StoredContractName'] = _STOREDCONTRACTNAME
DESCRIPTOR.message_types_by_name['StoredContractPackage'] = _STOREDCONTRACTPACKAGE
DESCRIPTOR.message_types_by_name['StoredContractPackageHash'] = _STOREDCONTRACTPACKAGEHASH
DESCRIPTOR.message_types_by_name['Transfer'] = _TRANSFER
DESCRIPTOR.message_types_by_name['DeployPayload'] = _DEPLOYPAYLOAD
DESCRIPTOR.message_types_by_name['Bond'] = _BOND
DESCRIPTOR.message_types_by_name['DeployItem'] = _DEPLOYITEM
DESCRIPTOR.message_types_by_name['ExecuteRequest'] = _EXECUTEREQUEST
DESCRIPTOR.message_types_by_name['ExecuteResponse'] = _EXECUTERESPONSE
DESCRIPTOR.message_types_by_name['ExecResult'] = _EXECRESULT
DESCRIPTOR.message_types_by_name['RootNotFound'] = _ROOTNOTFOUND
DESCRIPTOR.message_types_by_name['CommitRequest'] = _COMMITREQUEST
DESCRIPTOR.message_types_by_name['CommitResult'] = _COMMITRESULT
DESCRIPTOR.message_types_by_name['CommitResponse'] = _COMMITRESPONSE
DESCRIPTOR.message_types_by_name['Op'] = _OP
DESCRIPTOR.message_types_by_name['ReadOp'] = _READOP
DESCRIPTOR.message_types_by_name['WriteOp'] = _WRITEOP
DESCRIPTOR.message_types_by_name['AddOp'] = _ADDOP
DESCRIPTOR.message_types_by_name['NoOp'] = _NOOP
DESCRIPTOR.message_types_by_name['StorageError'] = _STORAGEERROR
DESCRIPTOR.message_types_by_name['BytesReprError'] = _BYTESREPRERROR
DESCRIPTOR.message_types_by_name['EarlyEndOfStream'] = _EARLYENDOFSTREAM
DESCRIPTOR.message_types_by_name['FormattingError'] = _FORMATTINGERROR
DESCRIPTOR.message_types_by_name['LeftOverBytes'] = _LEFTOVERBYTES
DESCRIPTOR.message_types_by_name['RkvError'] = _RKVERROR
DESCRIPTOR.message_types_by_name['OpEntry'] = _OPENTRY
DESCRIPTOR.message_types_by_name['ExecutionEffect'] = _EXECUTIONEFFECT
DESCRIPTOR.message_types_by_name['DeployError'] = _DEPLOYERROR
DESCRIPTOR.message_types_by_name['DeployResult'] = _DEPLOYRESULT
DESCRIPTOR.message_types_by_name['PostEffectsError'] = _POSTEFFECTSERROR
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
DESCRIPTOR.message_types_by_name['GenesisResult'] = _GENESISRESULT
DESCRIPTOR.message_types_by_name['GenesisDeployError'] = _GENESISDEPLOYERROR
DESCRIPTOR.message_types_by_name['GenesisResponse'] = _GENESISRESPONSE
DESCRIPTOR.message_types_by_name['ChainSpec'] = _CHAINSPEC
DESCRIPTOR.message_types_by_name['UpgradeRequest'] = _UPGRADEREQUEST
DESCRIPTOR.message_types_by_name['UpgradeResult'] = _UPGRADERESULT
DESCRIPTOR.message_types_by_name['UpgradeDeployError'] = _UPGRADEDEPLOYERROR
DESCRIPTOR.message_types_by_name['UpgradeResponse'] = _UPGRADERESPONSE
DESCRIPTOR.message_types_by_name['BidStateRequest'] = _BIDSTATEREQUEST
DESCRIPTOR.message_types_by_name['BidState'] = _BIDSTATE
DESCRIPTOR.message_types_by_name['BidStateResponse'] = _BIDSTATERESPONSE
DESCRIPTOR.message_types_by_name['DistributeRewardsRequest'] = _DISTRIBUTEREWARDSREQUEST
DESCRIPTOR.message_types_by_name['DistibuteRewardsError'] = _DISTIBUTEREWARDSERROR
DESCRIPTOR.message_types_by_name['DistributeRewardsResponse'] = _DISTRIBUTEREWARDSRESPONSE
DESCRIPTOR.message_types_by_name['SlashRequest'] = _SLASHREQUEST
DESCRIPTOR.message_types_by_name['SlashError'] = _SLASHERROR
DESCRIPTOR.message_types_by_name['SlashResponse'] = _SLASHRESPONSE
DESCRIPTOR.message_types_by_name['UnbondPayoutRequest'] = _UNBONDPAYOUTREQUEST
DESCRIPTOR.message_types_by_name['UnbondPayoutError'] = _UNBONDPAYOUTERROR
DESCRIPTOR.message_types_by_name['UnbondPayoutResponse'] = _UNBONDPAYOUTRESPONSE
DESCRIPTOR.message_types_by_name['RunGenesisRequest'] = _RUNGENESISREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DeployCode = _reflection.GeneratedProtocolMessageType('DeployCode', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYCODE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployCode)
  })
_sym_db.RegisterMessage(DeployCode)

StoredContractHash = _reflection.GeneratedProtocolMessageType('StoredContractHash', (_message.Message,), {
  'DESCRIPTOR' : _STOREDCONTRACTHASH,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.StoredContractHash)
  })
_sym_db.RegisterMessage(StoredContractHash)

StoredContractName = _reflection.GeneratedProtocolMessageType('StoredContractName', (_message.Message,), {
  'DESCRIPTOR' : _STOREDCONTRACTNAME,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.StoredContractName)
  })
_sym_db.RegisterMessage(StoredContractName)

StoredContractPackage = _reflection.GeneratedProtocolMessageType('StoredContractPackage', (_message.Message,), {
  'DESCRIPTOR' : _STOREDCONTRACTPACKAGE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.StoredContractPackage)
  })
_sym_db.RegisterMessage(StoredContractPackage)

StoredContractPackageHash = _reflection.GeneratedProtocolMessageType('StoredContractPackageHash', (_message.Message,), {
  'DESCRIPTOR' : _STOREDCONTRACTPACKAGEHASH,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.StoredContractPackageHash)
  })
_sym_db.RegisterMessage(StoredContractPackageHash)

Transfer = _reflection.GeneratedProtocolMessageType('Transfer', (_message.Message,), {
  'DESCRIPTOR' : _TRANSFER,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.Transfer)
  })
_sym_db.RegisterMessage(Transfer)

DeployPayload = _reflection.GeneratedProtocolMessageType('DeployPayload', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYPAYLOAD,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployPayload)
  })
_sym_db.RegisterMessage(DeployPayload)

Bond = _reflection.GeneratedProtocolMessageType('Bond', (_message.Message,), {
  'DESCRIPTOR' : _BOND,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.Bond)
  })
_sym_db.RegisterMessage(Bond)

DeployItem = _reflection.GeneratedProtocolMessageType('DeployItem', (_message.Message,), {
  'DESCRIPTOR' : _DEPLOYITEM,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployItem)
  })
_sym_db.RegisterMessage(DeployItem)

ExecuteRequest = _reflection.GeneratedProtocolMessageType('ExecuteRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ExecuteRequest)
  })
_sym_db.RegisterMessage(ExecuteRequest)

ExecuteResponse = _reflection.GeneratedProtocolMessageType('ExecuteResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTERESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ExecuteResponse)
  })
_sym_db.RegisterMessage(ExecuteResponse)

ExecResult = _reflection.GeneratedProtocolMessageType('ExecResult', (_message.Message,), {
  'DESCRIPTOR' : _EXECRESULT,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ExecResult)
  })
_sym_db.RegisterMessage(ExecResult)

RootNotFound = _reflection.GeneratedProtocolMessageType('RootNotFound', (_message.Message,), {
  'DESCRIPTOR' : _ROOTNOTFOUND,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.RootNotFound)
  })
_sym_db.RegisterMessage(RootNotFound)

CommitRequest = _reflection.GeneratedProtocolMessageType('CommitRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMITREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.CommitRequest)
  })
_sym_db.RegisterMessage(CommitRequest)

CommitResult = _reflection.GeneratedProtocolMessageType('CommitResult', (_message.Message,), {
  'DESCRIPTOR' : _COMMITRESULT,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.CommitResult)
  })
_sym_db.RegisterMessage(CommitResult)

CommitResponse = _reflection.GeneratedProtocolMessageType('CommitResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITRESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.CommitResponse)
  })
_sym_db.RegisterMessage(CommitResponse)

Op = _reflection.GeneratedProtocolMessageType('Op', (_message.Message,), {
  'DESCRIPTOR' : _OP,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.Op)
  })
_sym_db.RegisterMessage(Op)

ReadOp = _reflection.GeneratedProtocolMessageType('ReadOp', (_message.Message,), {
  'DESCRIPTOR' : _READOP,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ReadOp)
  })
_sym_db.RegisterMessage(ReadOp)

WriteOp = _reflection.GeneratedProtocolMessageType('WriteOp', (_message.Message,), {
  'DESCRIPTOR' : _WRITEOP,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.WriteOp)
  })
_sym_db.RegisterMessage(WriteOp)

AddOp = _reflection.GeneratedProtocolMessageType('AddOp', (_message.Message,), {
  'DESCRIPTOR' : _ADDOP,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.AddOp)
  })
_sym_db.RegisterMessage(AddOp)

NoOp = _reflection.GeneratedProtocolMessageType('NoOp', (_message.Message,), {
  'DESCRIPTOR' : _NOOP,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.NoOp)
  })
_sym_db.RegisterMessage(NoOp)

StorageError = _reflection.GeneratedProtocolMessageType('StorageError', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.StorageError)
  })
_sym_db.RegisterMessage(StorageError)

BytesReprError = _reflection.GeneratedProtocolMessageType('BytesReprError', (_message.Message,), {
  'DESCRIPTOR' : _BYTESREPRERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.BytesReprError)
  })
_sym_db.RegisterMessage(BytesReprError)

EarlyEndOfStream = _reflection.GeneratedProtocolMessageType('EarlyEndOfStream', (_message.Message,), {
  'DESCRIPTOR' : _EARLYENDOFSTREAM,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.EarlyEndOfStream)
  })
_sym_db.RegisterMessage(EarlyEndOfStream)

FormattingError = _reflection.GeneratedProtocolMessageType('FormattingError', (_message.Message,), {
  'DESCRIPTOR' : _FORMATTINGERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.FormattingError)
  })
_sym_db.RegisterMessage(FormattingError)

LeftOverBytes = _reflection.GeneratedProtocolMessageType('LeftOverBytes', (_message.Message,), {
  'DESCRIPTOR' : _LEFTOVERBYTES,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.LeftOverBytes)
  })
_sym_db.RegisterMessage(LeftOverBytes)

RkvError = _reflection.GeneratedProtocolMessageType('RkvError', (_message.Message,), {
  'DESCRIPTOR' : _RKVERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.RkvError)
  })
_sym_db.RegisterMessage(RkvError)

OpEntry = _reflection.GeneratedProtocolMessageType('OpEntry', (_message.Message,), {
  'DESCRIPTOR' : _OPENTRY,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.OpEntry)
  })
_sym_db.RegisterMessage(OpEntry)

ExecutionEffect = _reflection.GeneratedProtocolMessageType('ExecutionEffect', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONEFFECT,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ExecutionEffect)
  })
_sym_db.RegisterMessage(ExecutionEffect)

DeployError = _reflection.GeneratedProtocolMessageType('DeployError', (_message.Message,), {

  'OutOfGasError' : _reflection.GeneratedProtocolMessageType('OutOfGasError', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYERROR_OUTOFGASERROR,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployError.OutOfGasError)
    })
  ,

  'ExecutionError' : _reflection.GeneratedProtocolMessageType('ExecutionError', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYERROR_EXECUTIONERROR,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployError.ExecutionError)
    })
  ,
  'DESCRIPTOR' : _DEPLOYERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployError)
  })
_sym_db.RegisterMessage(DeployError)
_sym_db.RegisterMessage(DeployError.OutOfGasError)
_sym_db.RegisterMessage(DeployError.ExecutionError)

DeployResult = _reflection.GeneratedProtocolMessageType('DeployResult', (_message.Message,), {

  'PreconditionFailure' : _reflection.GeneratedProtocolMessageType('PreconditionFailure', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYRESULT_PRECONDITIONFAILURE,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployResult.PreconditionFailure)
    })
  ,

  'ExecutionResult' : _reflection.GeneratedProtocolMessageType('ExecutionResult', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYRESULT_EXECUTIONRESULT,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployResult.ExecutionResult)
    })
  ,
  'DESCRIPTOR' : _DEPLOYRESULT,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DeployResult)
  })
_sym_db.RegisterMessage(DeployResult)
_sym_db.RegisterMessage(DeployResult.PreconditionFailure)
_sym_db.RegisterMessage(DeployResult.ExecutionResult)

PostEffectsError = _reflection.GeneratedProtocolMessageType('PostEffectsError', (_message.Message,), {
  'DESCRIPTOR' : _POSTEFFECTSERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.PostEffectsError)
  })
_sym_db.RegisterMessage(PostEffectsError)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)

GenesisResult = _reflection.GeneratedProtocolMessageType('GenesisResult', (_message.Message,), {
  'DESCRIPTOR' : _GENESISRESULT,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.GenesisResult)
  })
_sym_db.RegisterMessage(GenesisResult)

GenesisDeployError = _reflection.GeneratedProtocolMessageType('GenesisDeployError', (_message.Message,), {
  'DESCRIPTOR' : _GENESISDEPLOYERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.GenesisDeployError)
  })
_sym_db.RegisterMessage(GenesisDeployError)

GenesisResponse = _reflection.GeneratedProtocolMessageType('GenesisResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENESISRESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.GenesisResponse)
  })
_sym_db.RegisterMessage(GenesisResponse)

ChainSpec = _reflection.GeneratedProtocolMessageType('ChainSpec', (_message.Message,), {

  'GenesisConfig' : _reflection.GeneratedProtocolMessageType('GenesisConfig', (_message.Message,), {

    'ExecConfig' : _reflection.GeneratedProtocolMessageType('ExecConfig', (_message.Message,), {

      'GenesisAccount' : _reflection.GeneratedProtocolMessageType('GenesisAccount', (_message.Message,), {
        'DESCRIPTOR' : _CHAINSPEC_GENESISCONFIG_EXECCONFIG_GENESISACCOUNT,
        '__module__' : 'ipc_pb2'
        # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig.GenesisAccount)
        })
      ,
      'DESCRIPTOR' : _CHAINSPEC_GENESISCONFIG_EXECCONFIG,
      '__module__' : 'ipc_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.GenesisConfig.ExecConfig)
      })
    ,
    'DESCRIPTOR' : _CHAINSPEC_GENESISCONFIG,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.GenesisConfig)
    })
  ,

  'DeployConfig' : _reflection.GeneratedProtocolMessageType('DeployConfig', (_message.Message,), {
    'DESCRIPTOR' : _CHAINSPEC_DEPLOYCONFIG,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.DeployConfig)
    })
  ,

  'HighwayConfig' : _reflection.GeneratedProtocolMessageType('HighwayConfig', (_message.Message,), {
    'DESCRIPTOR' : _CHAINSPEC_HIGHWAYCONFIG,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.HighwayConfig)
    })
  ,

  'CostTable' : _reflection.GeneratedProtocolMessageType('CostTable', (_message.Message,), {

    'WasmCosts' : _reflection.GeneratedProtocolMessageType('WasmCosts', (_message.Message,), {
      'DESCRIPTOR' : _CHAINSPEC_COSTTABLE_WASMCOSTS,
      '__module__' : 'ipc_pb2'
      # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.CostTable.WasmCosts)
      })
    ,
    'DESCRIPTOR' : _CHAINSPEC_COSTTABLE,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.CostTable)
    })
  ,

  'UpgradePoint' : _reflection.GeneratedProtocolMessageType('UpgradePoint', (_message.Message,), {
    'DESCRIPTOR' : _CHAINSPEC_UPGRADEPOINT,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.UpgradePoint)
    })
  ,

  'ActivationPoint' : _reflection.GeneratedProtocolMessageType('ActivationPoint', (_message.Message,), {
    'DESCRIPTOR' : _CHAINSPEC_ACTIVATIONPOINT,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec.ActivationPoint)
    })
  ,
  'DESCRIPTOR' : _CHAINSPEC,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.ChainSpec)
  })
_sym_db.RegisterMessage(ChainSpec)
_sym_db.RegisterMessage(ChainSpec.GenesisConfig)
_sym_db.RegisterMessage(ChainSpec.GenesisConfig.ExecConfig)
_sym_db.RegisterMessage(ChainSpec.GenesisConfig.ExecConfig.GenesisAccount)
_sym_db.RegisterMessage(ChainSpec.DeployConfig)
_sym_db.RegisterMessage(ChainSpec.HighwayConfig)
_sym_db.RegisterMessage(ChainSpec.CostTable)
_sym_db.RegisterMessage(ChainSpec.CostTable.WasmCosts)
_sym_db.RegisterMessage(ChainSpec.UpgradePoint)
_sym_db.RegisterMessage(ChainSpec.ActivationPoint)

UpgradeRequest = _reflection.GeneratedProtocolMessageType('UpgradeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPGRADEREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UpgradeRequest)
  })
_sym_db.RegisterMessage(UpgradeRequest)

UpgradeResult = _reflection.GeneratedProtocolMessageType('UpgradeResult', (_message.Message,), {
  'DESCRIPTOR' : _UPGRADERESULT,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UpgradeResult)
  })
_sym_db.RegisterMessage(UpgradeResult)

UpgradeDeployError = _reflection.GeneratedProtocolMessageType('UpgradeDeployError', (_message.Message,), {
  'DESCRIPTOR' : _UPGRADEDEPLOYERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UpgradeDeployError)
  })
_sym_db.RegisterMessage(UpgradeDeployError)

UpgradeResponse = _reflection.GeneratedProtocolMessageType('UpgradeResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPGRADERESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UpgradeResponse)
  })
_sym_db.RegisterMessage(UpgradeResponse)

BidStateRequest = _reflection.GeneratedProtocolMessageType('BidStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIDSTATEREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.BidStateRequest)
  })
_sym_db.RegisterMessage(BidStateRequest)

BidState = _reflection.GeneratedProtocolMessageType('BidState', (_message.Message,), {

  'Bid' : _reflection.GeneratedProtocolMessageType('Bid', (_message.Message,), {
    'DESCRIPTOR' : _BIDSTATE_BID,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.BidState.Bid)
    })
  ,
  'DESCRIPTOR' : _BIDSTATE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.BidState)
  })
_sym_db.RegisterMessage(BidState)
_sym_db.RegisterMessage(BidState.Bid)

BidStateResponse = _reflection.GeneratedProtocolMessageType('BidStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _BIDSTATERESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.BidStateResponse)
  })
_sym_db.RegisterMessage(BidStateResponse)

DistributeRewardsRequest = _reflection.GeneratedProtocolMessageType('DistributeRewardsRequest', (_message.Message,), {

  'ValidatorReward' : _reflection.GeneratedProtocolMessageType('ValidatorReward', (_message.Message,), {
    'DESCRIPTOR' : _DISTRIBUTEREWARDSREQUEST_VALIDATORREWARD,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DistributeRewardsRequest.ValidatorReward)
    })
  ,
  'DESCRIPTOR' : _DISTRIBUTEREWARDSREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DistributeRewardsRequest)
  })
_sym_db.RegisterMessage(DistributeRewardsRequest)
_sym_db.RegisterMessage(DistributeRewardsRequest.ValidatorReward)

DistibuteRewardsError = _reflection.GeneratedProtocolMessageType('DistibuteRewardsError', (_message.Message,), {
  'DESCRIPTOR' : _DISTIBUTEREWARDSERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DistibuteRewardsError)
  })
_sym_db.RegisterMessage(DistibuteRewardsError)

DistributeRewardsResponse = _reflection.GeneratedProtocolMessageType('DistributeRewardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISTRIBUTEREWARDSRESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.DistributeRewardsResponse)
  })
_sym_db.RegisterMessage(DistributeRewardsResponse)

SlashRequest = _reflection.GeneratedProtocolMessageType('SlashRequest', (_message.Message,), {

  'ValidatorSlash' : _reflection.GeneratedProtocolMessageType('ValidatorSlash', (_message.Message,), {
    'DESCRIPTOR' : _SLASHREQUEST_VALIDATORSLASH,
    '__module__' : 'ipc_pb2'
    # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.SlashRequest.ValidatorSlash)
    })
  ,
  'DESCRIPTOR' : _SLASHREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.SlashRequest)
  })
_sym_db.RegisterMessage(SlashRequest)
_sym_db.RegisterMessage(SlashRequest.ValidatorSlash)

SlashError = _reflection.GeneratedProtocolMessageType('SlashError', (_message.Message,), {
  'DESCRIPTOR' : _SLASHERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.SlashError)
  })
_sym_db.RegisterMessage(SlashError)

SlashResponse = _reflection.GeneratedProtocolMessageType('SlashResponse', (_message.Message,), {
  'DESCRIPTOR' : _SLASHRESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.SlashResponse)
  })
_sym_db.RegisterMessage(SlashResponse)

UnbondPayoutRequest = _reflection.GeneratedProtocolMessageType('UnbondPayoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNBONDPAYOUTREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UnbondPayoutRequest)
  })
_sym_db.RegisterMessage(UnbondPayoutRequest)

UnbondPayoutError = _reflection.GeneratedProtocolMessageType('UnbondPayoutError', (_message.Message,), {
  'DESCRIPTOR' : _UNBONDPAYOUTERROR,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UnbondPayoutError)
  })
_sym_db.RegisterMessage(UnbondPayoutError)

UnbondPayoutResponse = _reflection.GeneratedProtocolMessageType('UnbondPayoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _UNBONDPAYOUTRESPONSE,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.UnbondPayoutResponse)
  })
_sym_db.RegisterMessage(UnbondPayoutResponse)

RunGenesisRequest = _reflection.GeneratedProtocolMessageType('RunGenesisRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNGENESISREQUEST,
  '__module__' : 'ipc_pb2'
  # @@protoc_insertion_point(class_scope:io.casperlabs.ipc.RunGenesisRequest)
  })
_sym_db.RegisterMessage(RunGenesisRequest)



_EXECUTIONENGINESERVICE = _descriptor.ServiceDescriptor(
  name='ExecutionEngineService',
  full_name='io.casperlabs.ipc.ExecutionEngineService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=8896,
  serialized_end=9719,
  methods=[
  _descriptor.MethodDescriptor(
    name='commit',
    full_name='io.casperlabs.ipc.ExecutionEngineService.commit',
    index=0,
    containing_service=None,
    input_type=_COMMITREQUEST,
    output_type=_COMMITRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='query',
    full_name='io.casperlabs.ipc.ExecutionEngineService.query',
    index=1,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='execute',
    full_name='io.casperlabs.ipc.ExecutionEngineService.execute',
    index=2,
    containing_service=None,
    input_type=_EXECUTEREQUEST,
    output_type=_EXECUTERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='run_genesis',
    full_name='io.casperlabs.ipc.ExecutionEngineService.run_genesis',
    index=3,
    containing_service=None,
    input_type=_RUNGENESISREQUEST,
    output_type=_GENESISRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='upgrade',
    full_name='io.casperlabs.ipc.ExecutionEngineService.upgrade',
    index=4,
    containing_service=None,
    input_type=_UPGRADEREQUEST,
    output_type=_UPGRADERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='bid_state',
    full_name='io.casperlabs.ipc.ExecutionEngineService.bid_state',
    index=5,
    containing_service=None,
    input_type=_BIDSTATEREQUEST,
    output_type=_BIDSTATERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='distribute_rewards',
    full_name='io.casperlabs.ipc.ExecutionEngineService.distribute_rewards',
    index=6,
    containing_service=None,
    input_type=_DISTRIBUTEREWARDSREQUEST,
    output_type=_DISTRIBUTEREWARDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='slash',
    full_name='io.casperlabs.ipc.ExecutionEngineService.slash',
    index=7,
    containing_service=None,
    input_type=_SLASHREQUEST,
    output_type=_SLASHRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='unbond_payout',
    full_name='io.casperlabs.ipc.ExecutionEngineService.unbond_payout',
    index=8,
    containing_service=None,
    input_type=_UNBONDPAYOUTREQUEST,
    output_type=_UNBONDPAYOUTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_EXECUTIONENGINESERVICE)

DESCRIPTOR.services_by_name['ExecutionEngineService'] = _EXECUTIONENGINESERVICE

# @@protoc_insertion_point(module_scope)
